@@ -20,16 +20,17 @@ import socket
 import struct
 import time
 import traceback
+from contextlib import contextmanager
 from multiprocessing.synchronize import Event
 from typing import Any, Callable, Optional, Sequence, Tuple, Type
 
-from mosec.errors import MosecError
+from mosec.errors import MosecError, MosecTimeoutError
 from mosec.ipc import IPCWrapper
-from mosec.log import get_logger
+from mosec.log import get_internal_logger
 from mosec.protocol import HTTPStautsCode, Protocol
 from mosec.worker import Worker
 
-logger = get_logger()
+logger = get_internal_logger()
 
 
 CONN_MAX_RETRY = 10
@@ -41,6 +42,27 @@ STAGE_EGRESS = "egress"
 PROTOCOL_TIMEOUT = 2.0
 
 
+@contextmanager
+def set_mosec_timeout(duration: int):
+    """Context manager to set a timeout for a code block.
+
+    Args:
+        duration (float): the duration in seconds before timing out
+    """
+
+    def handler(signum, frame):
+        raise MosecTimeoutError(
+            f"[{signum}]`forward` timeout after {duration}s: {frame}"
+        )
+
+    signal.signal(signal.SIGALRM, handler)
+    signal.alarm(duration)
+    try:
+        yield
+    finally:
+        signal.alarm(0)
+
+
 class Coordinator:
     """Coordinator controls the data flow.
 
@@ -60,6 +82,7 @@ class Coordinator:
         stage_id: int,
         worker_id: int,
         ipc_wrapper: Optional[Callable[..., IPCWrapper]],
+        timeout: int,
     ):
         """Initialize the mosec coordinator.
 
@@ -74,6 +97,7 @@ class Coordinator:
             worker_id (int): identification number for worker processes at the same
                 stage.
             ipc_wrapper (IPCWrapper): IPC wrapper class to be initialized.
+            timeout (int): timeout for the `forward` function.
 
         Raises:
             TypeError: ipc_wrapper should inherit from `IPCWrapper`
@@ -82,7 +106,7 @@ class Coordinator:
         self.worker.worker_id = worker_id
         self.worker.max_batch_size = max_batch_size
         self.worker.stage = stage
-
+        self.timeout = timeout
         self.name = f"<{stage_id}|{worker.__name__}|{worker_id}>"
 
         self.protocol = Protocol(
@@ -250,11 +274,12 @@ class Coordinator:
             length = len(payloads)
             try:
                 data = [decoder(item) for item in payloads]
-                data = (
-                    self.worker.forward(data)
-                    if self.worker.max_batch_size > 1
-                    else (self.worker.forward(data[0]),)
-                )
+                with set_mosec_timeout(self.timeout):
+                    data = (
+                        self.worker.forward(data)
+                        if self.worker.max_batch_size > 1
+                        else (self.worker.forward(data[0]),)
+                    )
                 if len(data) != length:
                     raise ValueError(
                         "returned data size doesn't match the input data size:"
@@ -262,7 +287,7 @@ class Coordinator:
                     )
                 status = HTTPStautsCode.OK
                 payloads = [encoder(item) for item in data]
-            except MosecError as err:
+            except (MosecError, MosecTimeoutError) as err:
                 err_msg = str(err).replace("\n", " - ")
                 err_msg = err_msg if err_msg else err.msg
                 logger.info("%s %s: %s", self.name, err.msg, err_msg)
