@@ -25,6 +25,9 @@ from typing import Any, MutableMapping
 from mosec.args import mosec_args
 
 MOSEC_LOG_NAME = __name__
+MOSEC_LOG_PREFIX = "mosec"
+USER_LOG_NAME = "moser.user_log"
+USER_LOG_PREFIX = "user"
 
 
 class MosecFormat(logging.Formatter):
@@ -52,16 +55,19 @@ class DebugFormat(MosecFormat):
     Reset = "\x1b[0m"
 
     default_format = (
-        "%(asctime)s %(levelname)s %(filename)s:%(lineno)s"
+        "%(asctime)s %(levelname)s %(prefix)s::%(filename)s:%(lineno)s"
         " [%(process)d]: %(message)s"
     )
 
-    def __init__(self, fmt: str | None = None, datefmt: str | None = None) -> None:
+    def __init__(
+        self, fmt: str | None = None, datefmt: str | None = None, prefix: str = ""
+    ) -> None:
         """Init with `%` style format.
 
         Args:
             fmt (str): logging message format (% style)
             datefmt (str): datatime format
+            prefix (str): prefix of target
         """
         # partially align with rust tracing_subscriber
         self.colors = {
@@ -72,6 +78,7 @@ class DebugFormat(MosecFormat):
             logging.CRITICAL: self.Purple,
         }
         super().__init__(fmt or self.default_format, datefmt, "%")
+        self.prefix = prefix
 
     def format_level(self, name: str, level: int) -> str:
         """Format a level name with the corresponding color."""
@@ -82,8 +89,8 @@ class DebugFormat(MosecFormat):
     def formatMessage(self, record: logging.LogRecord) -> str:
         """Format the logging with colorful level names."""
         fmt = self.default_format.replace(
-            "%(levelname)s",
-            self.format_level(record.levelname, record.levelno),
+            "%(levelname)s %(prefix)s",
+            f"{self.format_level(record.levelname, record.levelno)} {self.prefix}",
         )
         return fmt % record.__dict__
 
@@ -91,6 +98,19 @@ class DebugFormat(MosecFormat):
 class JSONFormat(MosecFormat):
     """JSON log formatter."""
 
+    def __init__(
+        self, fmt: str | None = None, datefmt: str | None = None, prefix: str = ""
+    ) -> None:
+        """Init with `%` style format.
+
+        Args:
+            fmt (str): logging message format (% style)
+            datefmt (str): datatime format
+            prefix (str): prefix of target
+        """
+        super().__init__(fmt, datefmt, "%")
+        self.prefix = prefix
+
     def format(self, record: logging.LogRecord) -> str:
         """Format to a JSON string."""
         # yet another mypy type-check issue
@@ -101,7 +121,7 @@ class JSONFormat(MosecFormat):
             "fields": {
                 "message": record.getMessage(),
             },
-            "target": f"{record.filename}:{record.funcName}",
+            "target": f"{self.prefix}::{record.filename}:{record.funcName}",
         }
         if record.exc_info:
             if not record.exc_text:
@@ -112,9 +132,9 @@ class JSONFormat(MosecFormat):
         return json.dumps(res)
 
 
-def use_log(level: int, formatter: logging.Formatter):
+def use_log(level: int, formatter: logging.Formatter, logger_name: str):
     """Configure the global log."""
-    logger = logging.getLogger(MOSEC_LOG_NAME)
+    logger = logging.getLogger(logger_name)
     logger.setLevel(level)
     if not logger.handlers:
         stream = logging.StreamHandler()
@@ -123,21 +143,32 @@ def use_log(level: int, formatter: logging.Formatter):
     return logger
 
 
-def use_pretty_log(level: int = logging.DEBUG):
+def use_pretty_log(level: int = logging.DEBUG, prefix: str = "", logger_name: str = ""):
     """Enable colorful log."""
-    return use_log(level, DebugFormat())
+    return use_log(level, DebugFormat(prefix=prefix), logger_name)
 
 
-def use_json_log(level: int = logging.INFO):
+def use_json_log(level: int = logging.INFO, prefix: str = "", logger_name: str = ""):
     """Enable JSON format log."""
-    return use_log(level, JSONFormat())
+    return use_log(level, JSONFormat(prefix=prefix), logger_name)
 
 
 def get_logger():
-    """Get the logger used by mosec for multiprocessing."""
+    """Get the logger used by mosec user for multiprocessing."""
+    prefix = USER_LOG_PREFIX
+    logger_name = USER_LOG_NAME
     if os.environ.get(MOSEC_LOG_NAME, "") == str(logging.DEBUG):
-        return use_pretty_log()
-    return use_json_log()
+        return use_pretty_log(prefix=prefix, logger_name=logger_name)
+    return use_json_log(prefix=prefix, logger_name=logger_name)
+
+
+def get_internal_logger():
+    """Get the logger used by mosec internally for multiprocessing."""
+    prefix = MOSEC_LOG_PREFIX
+    logger_name = MOSEC_LOG_NAME
+    if os.environ.get(MOSEC_LOG_NAME, "") == str(logging.DEBUG):
+        return use_pretty_log(prefix=prefix, logger_name=logger_name)
+    return use_json_log(prefix=prefix, logger_name=logger_name)
 
 
 def set_logger(debug=False):
